# Any item shoud respond at least to :title, :link, :pubdate, :category, :guid, :description, :guid_is_permalink.
# 
# The simplest way to achieve that is use a decorator:
# 
# class PostRssItem < Fullstack::Rss::Item
#   
#   # ============
#   # = Required =
#   # ============
#   
#   delegate :title, :to => :object
#   
#   def link
#     site_post_url(object)
#   end
#   
#   def pubdate
#     object.created_at.xmlschema
#   end
#   
#   def category
#     cdata(object.category.title) # cdata helper is provided by Fullstack::Rss::ItemDecorator
#   end
#   
#   def description
#     cdata(object.intro.html_safe)
#   end
#   
#   # ============
#   # = Optional =
#   # ============
#   
#   def guid
#     link # this is the default 
#   end
#   
#   def guid_is_permalink?
#     false # this is also the default
#   end
# 
# end

module Fullstack
  module Rss
    class Item
      
      attr_accessor :object
      def initialize(object)
        @object = object
      end
  
      def guid
        link
      end
        
      def guid_is_permalink?
        false
      end
      
      protected
      
      def cdata(text)
        "<![#{text}]]>".html_safe
      end
      
    end
  end
end